@@ -1,24 +1,10 @@
 #=====================================================================
-# SQL-Ledger Accounting
-# Copyright (C) 2001
+# SQL-Ledger ERP
+# Copyright (C) 2006
 #
 #  Author: DWS Systems Inc.
-#     Web: http://www.sql-ledger.org
+#     Web: http://www.sql-ledger.com
 #
-#  Contributors:
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #======================================================================
 #
 # chart of accounts
@@ -36,15 +22,21 @@ sub all_accounts {
   # connect to database
   my $dbh = $form->dbconnect($myconfig);
 
-  my $query = qq|SELECT accno,
-                 SUM(acc_trans.amount) AS amount
-                 FROM chart, acc_trans
-		 WHERE chart.id = acc_trans.chart_id
-		 GROUP BY accno|;
+  my $ref;
+  
+  my %defaults = $form->get_defaults($dbh, \@{['precision', 'company']});
+  for (keys %defaults) { $form->{$_} = $defaults{$_} }
+ 
+  my $query = qq|SELECT c.accno,
+                 SUM(ac.amount) AS amount
+                 FROM chart c
+		 JOIN acc_trans ac ON (ac.chart_id = c.id)
+		 WHERE ac.approved = '1'
+		 GROUP BY c.accno|;
   my $sth = $dbh->prepare($query);
   $sth->execute || $form->dberror($query);
 
-  while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
+  while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
     $amount{$ref->{accno}} = $ref->{amount}
   }
   $sth->finish;
@@ -61,21 +53,24 @@ sub all_accounts {
   $sth->finish;
 
   $query = qq|SELECT c.id, c.accno, c.description, c.charttype, c.gifi_accno,
-              c.category, c.link
+              c.category, c.link,
+	      l.description AS translation
               FROM chart c
-	      ORDER BY accno|;
+	      LEFT JOIN translation l ON (l.trans_id = c.id AND l.language_code = '$myconfig->{countrycode}')
+	      ORDER BY c.accno|;
   $sth = $dbh->prepare($query);
   $sth->execute || $form->dberror($query);
  
-  while (my $ca = $sth->fetchrow_hashref(NAME_lc)) {
-    $ca->{amount} = $amount{$ca->{accno}};
-    $ca->{gifi_description} = $gifi{$ca->{gifi_accno}};
-    if ($ca->{amount} < 0) {
-      $ca->{debit} = $ca->{amount} * -1;
+  while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
+    $ref->{amount} = $amount{$ref->{accno}};
+    $ref->{gifi_description} = $gifi{$ref->{gifi_accno}};
+    if ($ref->{amount} < 0) {
+      $ref->{debit} = $ref->{amount} * -1;
     } else {
-      $ca->{credit} = $ca->{amount};
+      $ref->{credit} = $ref->{amount};
     }
-    push @{ $form->{CA} }, $ca;
+    $ref->{description} = $ref->{translation} if $ref->{translation};
+    push @{ $form->{CA} }, $ref;
   }
 
   $sth->finish;
@@ -90,6 +85,10 @@ sub all_transactions {
   # connect to database
   my $dbh = $form->dbconnect($myconfig);
 
+
+  my %defaults = $form->get_defaults($dbh, \@{['precision', 'company']});
+  for (keys %defaults) { $form->{$_} = $defaults{$_} }
+    
   # get chart_id
   my $query = qq|SELECT id FROM chart
                  WHERE accno = '$form->{accno}'|;
@@ -117,7 +116,7 @@ sub all_transactions {
 		|;
   }
   if ($form->{todate}) {
-    $todate_where .= qq|
+    $todate_where = qq|
                  AND ac.transdate <= '$form->{todate}'
 		|;
   }
@@ -140,7 +139,7 @@ sub all_transactions {
   my $union;
   
   ($null, $department_id) = split /--/, $form->{department};
- 
+  
   if ($department_id) {
     $dpt_join = qq|
                    JOIN department t ON (t.id = a.department_id)
@@ -150,7 +149,6 @@ sub all_transactions {
 		  |;
   }
 
- 
   my $project;
   my $project_id;
   if ($form->{projectnumber}) {
@@ -162,10 +160,11 @@ sub all_transactions {
 
   if ($form->{accno} || $form->{gifi_accno}) {
     # get category for account
-    $query = qq|SELECT description, category, link, contra
-                FROM chart
-		WHERE accno = '$form->{accno}'|;
-
+    $query = qq|SELECT c.description, c.category, c.link, c.contra,
+                l.description AS translation
+                FROM chart c
+		LEFT JOIN translation l ON (l.trans_id = c.id AND l.language_code = '$myconfig->{countrycode}')
+		WHERE c.accno = '$form->{accno}'|;
     if ($form->{accounttype} eq 'gifi') {
       $query = qq|SELECT description, category, link, contra
                 FROM chart
@@ -173,18 +172,19 @@ sub all_transactions {
 		AND charttype = 'A'|;
     }
 
-    ($form->{description}, $form->{category}, $form->{link}, $form->{contra}) = $dbh->selectrow_array($query);
+    ($form->{description}, $form->{category}, $form->{link}, $form->{contra}, $form->{translation}) = $dbh->selectrow_array($query);
+
+    $form->{description} = $form->{translation} if $form->{translation};
     
     if ($form->{fromdate}) {
-      
+
       if ($department_id) {
-
-	# get beginning balance
-	$query = "";
-	$union = "";
 	
-	for (qw(ar ap gl)) {
+	$query = ""; 
+	$union = "";
 
+	for (qw(ar ap gl)) {
+	  
 	  if ($form->{accounttype} eq 'gifi') {
 	    $query = qq|
 	                $union
@@ -193,30 +193,30 @@ sub all_transactions {
 			JOIN $_ a ON (a.id = ac.trans_id)
 			JOIN chart c ON (ac.chart_id = c.id)
 			WHERE c.gifi_accno = '$form->{gifi_accno}'
+			AND ac.approved = '1'
 			AND ac.transdate < '$form->{fromdate}'
 			AND a.department_id = $department_id
 			$project
 			|;
 		      
 	  } else {
-	  
-	    $query .= qq|
+
+	    $query = qq|
 			$union
 			SELECT SUM(ac.amount)
 			FROM acc_trans ac
 			JOIN $_ a ON (a.id = ac.trans_id)
 			JOIN chart c ON (ac.chart_id = c.id)
 			WHERE c.accno = '$form->{accno}'
+			AND ac.approved = '1'
 			AND ac.transdate < '$form->{fromdate}'
 			AND a.department_id = $department_id
 			$project
 			|;
 	  }
 
-	  $union = qq|
-	            UNION ALL|;
 	}
-
+	
       } else {
 	
 	if ($form->{accounttype} eq 'gifi') {
@@ -224,6 +224,7 @@ sub all_transactions {
 		    FROM acc_trans ac
 		    JOIN chart c ON (ac.chart_id = c.id)
 		    WHERE c.gifi_accno = '$form->{gifi_accno}'
+		    AND ac.approved = '1'
 		    AND ac.transdate < '$form->{fromdate}'
 		    $project
 		    |;
@@ -232,20 +233,20 @@ sub all_transactions {
 		      FROM acc_trans ac
 		      JOIN chart c ON (ac.chart_id = c.id)
 		      WHERE c.accno = '$form->{accno}'
+		      AND ac.approved = '1'
 		      AND ac.transdate < '$form->{fromdate}'
 		      $project
 		      |;
 	}
-
       }
-
+	
       ($form->{balance}) = $dbh->selectrow_array($query);
       
     }
   }
 
   $query = "";
-  $union = "";
+  my $union = "";
 
   foreach my $id (@id) {
     
@@ -254,11 +255,12 @@ sub all_transactions {
                  SELECT a.id, a.reference, a.description, ac.transdate,
 	         $false AS invoice, ac.amount, 'gl' as module, ac.cleared,
 		 ac.source,
-		 '' AS till, ac.chart_id
+		 '' AS till, ac.chart_id, '0' AS vc_id
 		 FROM gl a
 		 JOIN acc_trans ac ON (ac.trans_id = a.id)
 		 $dpt_join
 		 WHERE ac.chart_id = $id
+		 AND ac.approved = '1'
 		 $fromdate_where
 		 $todate_where
 		 $dpt_where
@@ -269,12 +271,13 @@ sub all_transactions {
                  SELECT a.id, a.invnumber, c.name, ac.transdate,
 	         a.invoice, ac.amount, 'ar' as module, ac.cleared,
 		 ac.source,
-		 a.till, ac.chart_id
+		 a.till, ac.chart_id, c.id AS vc_id
 		 FROM ar a
 		 JOIN acc_trans ac ON (ac.trans_id = a.id)
 		 JOIN customer c ON (a.customer_id = c.id)
 		 $dpt_join
 		 WHERE ac.chart_id = $id
+		 AND ac.approved = '1'
 		 $fromdate_where
 		 $todate_where
 		 $dpt_where
@@ -285,12 +288,13 @@ sub all_transactions {
                  SELECT a.id, a.invnumber, v.name, ac.transdate,
 	         a.invoice, ac.amount, 'ap' as module, ac.cleared,
 		 ac.source,
-		 a.till, ac.chart_id
+		 a.till, ac.chart_id, v.id AS vc_id
 		 FROM ap a
 		 JOIN acc_trans ac ON (ac.trans_id = a.id)
 		 JOIN vendor v ON (a.vendor_id = v.id)
 		 $dpt_join
 		 WHERE ac.chart_id = $id
+		 AND ac.approved = '1'
 		 $fromdate_where
 		 $todate_where
 		 $dpt_where
@@ -312,6 +316,7 @@ sub all_transactions {
               JOIN acc_trans ac ON (ac.chart_id = c.id)
               WHERE ac.amount >= 0
 	      AND (c.link = 'AR' OR c.link = 'AP')
+	      AND ac.approved = '1'
 	      AND ac.trans_id = ?|;
   my $dr = $dbh->prepare($query) || $form->dberror($query);
   
@@ -319,6 +324,7 @@ sub all_transactions {
               JOIN acc_trans ac ON (ac.chart_id = c.id)
               WHERE ac.amount < 0
 	      AND (c.link = 'AR' OR c.link = 'AP')
+	      AND ac.approved = '1'
 	      AND ac.trans_id = ?|;
   my $cr = $dbh->prepare($query) || $form->dberror($query);
   
@@ -326,56 +332,60 @@ sub all_transactions {
   my $chart_id;
   my %accno;
   
-  while (my $ca = $sth->fetchrow_hashref(NAME_lc)) {
+  while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
     
     # gl
-    if ($ca->{module} eq "gl") {
-      $ca->{module} = "gl";
+    if ($ref->{module} eq "gl") {
+      $ref->{module} = "gl";
+      $ref->{vc_id} = 0;
+      $ref->{db} = "";
     }
 
     # ap
-    if ($ca->{module} eq "ap") {
-      $ca->{module} = ($ca->{invoice}) ? 'ir' : 'ap';
-      $ca->{module} = 'ps' if $ca->{till};
+    if ($ref->{module} eq "ap") {
+      $ref->{module} = ($ref->{invoice}) ? 'ir' : 'ap';
+      $ref->{module} = 'ps' if $ref->{till};
+      $ref->{db} = "vendor";
     }
 
     # ar
-    if ($ca->{module} eq "ar") {
-      $ca->{module} = ($ca->{invoice}) ? 'is' : 'ar';
-      $ca->{module} = 'ps' if $ca->{till};
+    if ($ref->{module} eq "ar") {
+      $ref->{module} = ($ref->{invoice}) ? 'is' : 'ar';
+      $ref->{module} = 'ps' if $ref->{till};
+      $ref->{db} = "customer";
     }
 
-    if ($ca->{amount}) {
+    if ($ref->{amount}) {
       %accno = ();
 
-      if ($ca->{amount} < 0) {
-	$ca->{debit} = $ca->{amount} * -1;
-	$ca->{credit} = 0;
-	$dr->execute($ca->{id});
-	$ca->{accno} = ();
+      if ($ref->{amount} < 0) {
+	$ref->{debit} = $ref->{amount} * -1;
+	$ref->{credit} = 0;
+	$dr->execute($ref->{id});
+	$ref->{accno} = ();
 	while (($chart_id, $accno) = $dr->fetchrow_array) {
-	  $accno{$accno} = 1 if $chart_id ne $ca->{chart_id};
+	  $accno{$accno} = 1 if $chart_id ne $ref->{chart_id};
 	}
 	$dr->finish;
 	
-	for (sort keys %accno) { push @{ $ca->{accno} }, "$_ " }
+	for (sort keys %accno) { push @{ $ref->{accno} }, "$_ " }
 
       } else {
-	$ca->{credit} = $ca->{amount};
-	$ca->{debit} = 0;
+	$ref->{credit} = $ref->{amount};
+	$ref->{debit} = 0;
 	
-	$cr->execute($ca->{id});
-	$ca->{accno} = ();
+	$cr->execute($ref->{id});
+	$ref->{accno} = ();
 	while (($chart_id, $accno) = $cr->fetchrow_array) {
-	  $accno{$accno} = 1 if $chart_id ne $ca->{chart_id};
+	  $accno{$accno} = 1 if $chart_id ne $ref->{chart_id};
 	}
 	$cr->finish;
 
-	for (keys %accno) { push @{ $ca->{accno} }, "$_ " }
+	for (keys %accno) { push @{ $ref->{accno} }, "$_ " }
 
       }
 
-      push @{ $form->{CA} }, $ca;
+      push @{ $form->{CA} }, $ref;
     }
     
   }
