@@ -1,24 +1,10 @@
 #=====================================================================
-# SQL-Ledger Accounting
-# Copyright (C) 2000
+# SQL-Ledger ERP
+# Copyright (C) 2006
 #
 #  Author: DWS Systems Inc.
-#     Web: http://www.sql-ledger.org
+#     Web: http://www.sql-ledger.com
 #
-#  Contributors: Jim Rawlings <jim@your-dba.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #=====================================================================
 #
 # user related functions
@@ -104,12 +90,12 @@ sub login {
 	return -1;
       }
     }
-   
+
     $self->{password} = $form->{password};
     $self->create_config("$userspath/$self->{login}.conf");
     
     $self->{password} = $form->{password};
-    
+      
     do "$userspath/$self->{login}.conf";
     $myconfig{dbpasswd} = unpack 'u', $myconfig{dbpasswd};
   
@@ -117,11 +103,21 @@ sub login {
     my $dbh = DBI->connect($myconfig{dbconnect}, $myconfig{dbuser}, $myconfig{dbpasswd}) or $self->error($DBI::errstr);
 
     # we got a connection, check the version
-    my $query = qq|SELECT version FROM defaults|;
+    
+    my %defaults;
+    my $dbversion;
+
+    my $query = qq|SELECT * FROM defaults|;
     my $sth = $dbh->prepare($query);
     $sth->execute || $form->dberror($query);
 
-    my ($dbversion) = $sth->fetchrow_array;
+    if ($sth->{NAME}->[0] eq 'fldname') {
+      %defaults = $form->get_defaults($dbh, \@{['version']});
+      $dbversion = $defaults{version};
+    } else {
+      $query = qq|SELECT version FROM defaults|;
+      ($dbversion) = $dbh->selectrow_array($query);
+    }
     $sth->finish;
 
     # add login to employee table if it does not exist
@@ -129,18 +125,12 @@ sub login {
     my $login = $self->{login};
     $login =~ s/@.*//;
     $query = qq|SELECT id FROM employee WHERE login = '$login'|;
-    $sth = $dbh->prepare($query);
-    $sth->execute;
-
-    my ($id) = $sth->fetchrow_array;
-    $sth->finish;
+    my ($id) = $dbh->selectrow_array($query);
 
     if (! $id) {
-      my ($employeenumber) = $form->update_defaults(\%myconfig, "employeenumber", $dbh);
-      
-      $query = qq|INSERT INTO employee (login, employeenumber, name, workphone,
+      $query = qq|INSERT INTO employee (login, name, workphone,
                   role)
-                  VALUES ('$login', '$employeenumber', '$myconfig{name}',
+                  VALUES ('$login', '$myconfig{name}',
 		  '$myconfig{tel}', '$myconfig{role}')|;
       $dbh->do($query);
     }
@@ -198,21 +188,19 @@ sub dbconnect_vars {
 	'dd/mm/yy' => 'set DateStyle to \'SQL, EUROPEAN\'',
 	'dd-mm-yy' => 'set DateStyle to \'POSTGRES, EUROPEAN\'',
 	'dd.mm.yy' => 'set DateStyle to \'GERMAN\''
-	     },
-     'Oracle' => {
-	'yy-mm-dd' => 'ALTER SESSION SET NLS_DATE_FORMAT = \'YY-MM-DD\'',
-	'mm/dd/yy' => 'ALTER SESSION SET NLS_DATE_FORMAT = \'MM/DD/YY\'',
-	'mm-dd-yy' => 'ALTER SESSION SET NLS_DATE_FORMAT = \'MM-DD-YY\'',
-	'dd/mm/yy' => 'ALTER SESSION SET NLS_DATE_FORMAT = \'DD/MM/YY\'',
-	'dd-mm-yy' => 'ALTER SESSION SET NLS_DATE_FORMAT = \'DD-MM-YY\'',
-	'dd.mm.yy' => 'ALTER SESSION SET NLS_DATE_FORMAT = \'DD.MM.YY\'',
-	         }
+	     }
      );
 
+  if ($form->{dbdriver} eq 'Oracle') {
+    $dboptions{Oracle}{$form->{dateformat}} = qq|ALTER SESSION SET NLS_DATE_FORMAT = '$form->{dateformat}'|;
+  }
+  if ($form->{dbdriver} eq 'Sybase') {
+    $dboptions{Sybase}{$form->{dateformat}} = qq|SET DateFormat $form->{dateformat}|;
+  }
 
   $form->{dboptions} = $dboptions{$form->{dbdriver}}{$form->{dateformat}};
 
-  if ($form->{dbdriver} =~ /Pg/) {
+  if ($form->{dbdriver} =~ /(Pg|Sybase)/) {
     $form->{dbconnect} = "dbi:$form->{dbdriver}:dbname=$db";
   }
 
@@ -234,8 +222,7 @@ sub dbdrivers {
 
   my @drivers = DBI->available_drivers();
 
-#  return (grep { /(Pg|Oracle|DB2)/ } @drivers);
-  return (grep { /Pg$/ } @drivers);
+  return (grep { /(Sybase|Pg)/ } @drivers);
 
 }
 
@@ -302,7 +289,22 @@ sub dbsources {
     }
   }
 
+  if ($form->{dbdriver} eq 'Sybase') {
 
+    $query = qq|SELECT schemaname FROM syscat.schemata|;
+    
+    if ($form->{only_acc_db}) {
+      $query = qq|SELECT tabschema FROM syscat.tables WHERE tabname = 'DEFAULTS'|;
+    }
+    
+    $sth = $dbh->prepare($query);
+    $sth->execute || $form->dberror($query);
+     
+    while (my ($db) = $sth->fetchrow_array) {
+      push @dbsources, $db;
+    }
+  }
+  
 # JJR
   if ($form->{dbdriver} eq 'DB2') {
     if ($form->{only_acc_db}) {
@@ -336,9 +338,11 @@ sub dbcreate {
   my ($self, $form) = @_;
 
   my %dbcreate = ( 'Pg' => qq|CREATE DATABASE "$form->{db}"|,
+                'Sybase' => qq|CREATE DATABASE $form->{db}|,
                'Oracle' => qq|CREATE USER "$form->{db}" DEFAULT TABLESPACE USERS TEMPORARY TABLESPACE TEMP IDENTIFIED BY "$form->{db}"|);
 
   $dbcreate{Pg} .= " WITH ENCODING = '$form->{encoding}'" if $form->{encoding};
+  $dbcreate{Sybase} .= " CHARACTER SET $form->{encoding}" if $form->{encoding};
   
   $form->{sid} = $form->{dbdefault};
   &dbconnect_vars($form, $form->{dbdefault});
@@ -456,16 +460,17 @@ sub process_query {
   close FH;
  
 }
-  
+
 
 
 sub dbdelete {
   my ($self, $form) = @_;
 
   my %dbdelete = ( 'Pg' => qq|DROP DATABASE "$form->{db}"|,
+                'Sybase' => qq|DROP DATABASE $form->{db}|,
                'Oracle' => qq|DROP USER $form->{db} CASCADE|
 	         );
-  
+
   $form->{sid} = $form->{dbdefault};
   &dbconnect_vars($form, $form->{dbdefault});
   my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
@@ -519,44 +524,53 @@ sub dbneedsupdate {
 
   my %dbsources = ();
   my $query;
-  
+
   $form->{sid} = $form->{dbdefault};
   &dbconnect_vars($form, $form->{dbdefault});
 
   my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
 
+  my $sth;
+  my $version;
+  my %defaults;
+
   if ($form->{dbdriver} =~ /Pg/) {
 
     $query = qq|SELECT d.datname FROM pg_database d, pg_user u
                 WHERE d.datdba = u.usesysid
 		AND u.usename = '$form->{dbuser}'|;
-    my $sth = $dbh->prepare($query);
+
+    $sth = $dbh->prepare($query);
     $sth->execute || $form->dberror($query);
-    
+
     while (my ($db) = $sth->fetchrow_array) {
-
-      next if ($db =~ /^template/);
-
-      &dbconnect_vars($form, $db);
       
+      next if ($db =~ /^template/);
+      
+      &dbconnect_vars($form, $db);
+     
       my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
 
       $query = qq|SELECT tablename FROM pg_tables
 		  WHERE tablename = 'defaults'|;
-      my $sth = $dbh->prepare($query);
-      $sth->execute || $form->dberror($query);
 
-      if ($sth->fetchrow_array) {
-	$query = qq|SELECT version FROM defaults|;
+      if ($dbh->selectrow_array($query)) {
+	$query = qq|SELECT * FROM defaults|;
 	my $sth = $dbh->prepare($query);
-	$sth->execute;
-	
-	if (my ($version) = $sth->fetchrow_array) {
-	  $dbsources{$db} = $version;
+	$sth->execute || $form->dberror($query);
+
+	if ($sth->{NAME}->[0] eq 'fldname') {
+	  %defaults = $form->get_defaults($dbh, \@{['version']});
+	  $version = $defaults{version};
+	} else {
+	  $query = qq|SELECT version FROM defaults|;
+	  ($version) = $dbh->selectrow_array($query);
 	}
 	$sth->finish;
+
+	$dbsources{$db} = $version if $version;
       }
-      $sth->finish;
+      
       $dbh->disconnect;
     }
     $sth->finish;
@@ -577,15 +591,52 @@ sub dbneedsupdate {
       &dbconnect_vars($form, $db);
       
       my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
-
-      $query = qq|SELECT version FROM defaults|;
-      my $sth = $dbh->prepare($query);
-      $sth->execute;
       
-      if (my ($version) = $sth->fetchrow_array) {
-	$dbsources{$db} = $version;
+      $query = qq|SELECT * FROM defaults|;
+      my $sth->execute || $form->dberror($query);
+      
+      if ($sth->{NAME}->[0] eq 'fldname') {
+	%defaults = $form->get_defaults($dbh, \@{['version']});
+	$version = $defaults{version};
+      } else {
+	$query = qq|SELECT version FROM defaults|;
+	($version) = $dbh->selectrow_array($query);
       }
       $sth->finish;
+
+      $dbsources{$db} = $version if $version;
+      
+      $dbh->disconnect;
+    }
+    $sth->finish;
+  }
+
+  if ($form->{dbdriver} eq 'Sybase') {
+    $query = qq|SELECT tabschema FROM syscat.tables WHERE tabname = 'DEFAULTS'|;
+    $sth = $dbh->prepare($query);
+    $sth->execute || $form->dberror($query);
+ 
+    while (my ($db) = $sth->fetchrow_array) {
+      
+      &dbconnect_vars($form, $db);
+     
+      my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
+
+      $query = qq|SELECT * FROM defaults|;
+      my $sth = $dbh->prepare($query);
+      $sth->execute || $form->dberror($query);
+
+      if ($sth->{NAME}->[0] eq 'fldname') {
+	%defaults = $form->get_defaults($dbh, \@{['version']});
+	$version = $defaults{version};
+      } else {
+	$query = qq|SELECT version FROM defaults|;
+	($version) = $dbh->selectrow_array($query);
+      }
+      $sth->finish;
+
+      $dbsources{$db} = $version if $version;
+      
       $dbh->disconnect;
     }
     $sth->finish;
@@ -605,14 +656,12 @@ sub dbneedsupdate {
 
       my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
 
-      $query = qq|SELECT version FROM defaults|;
-      my $sth = $dbh->prepare($query);
-      $sth->execute;
-
-      if (my ($version) = $sth->fetchrow_array) {
+      my %defaults = $form->get_defaults($dbh, \@{['version']});
+      
+      if (my $version = $defaults{version}) {
 	$dbsources{$db} = $version;
       }
-      $sth->finish;
+
       $dbh->disconnect;
     }
     $sth->finish;
@@ -657,12 +706,20 @@ sub dbupdate {
     my $dbh = DBI->connect($form->{dbconnect}, $form->{dbuser}, $form->{dbpasswd}) or $form->dberror;
 
     # check version
-    $query = qq|SELECT version FROM defaults|;
+    $query = qq|SELECT * FROM defaults|;
     my $sth = $dbh->prepare($query);
-    # no error check, let it fall through
-    $sth->execute;
+    $sth->execute || $form->dberror($query);
+    
+    my %defaults;
+    my $version;
 
-    my $version = $sth->fetchrow_array;
+    if ($sth->{NAME}->[0] eq 'fldname') {
+      %defaults = $form->get_defaults($dbh, \@{['version']});
+      $version = $defaults{version};
+    } else {
+      $query = qq|SELECT version FROM defaults|;
+      ($version) = $dbh->selectrow_array($query);
+    }
     $sth->finish;
     
     next unless $version;
@@ -746,13 +803,13 @@ sub create_config {
   my ($self, $filename) = @_;
 
   @config = &config_vars;
-
+  
   my $password = $self->{password};
   my $key = "";
-  
+
   $self->{sessionkey} = "";
   $self->{sessioncookie} = "";
-  
+
   if ($self->{password}) {
     my $t = time + $self->{timeout};
     srand( time() ^ ($$ + ($$ << 15)) );
@@ -776,6 +833,7 @@ sub create_config {
     $self->{password} = crypt $self->{password}, substr($self->{login}, 0, 2) if ! $self->{encrypted};
   }
 
+  umask(002);
   open(CONF, ">$filename") or $self->error("$filename : $!");
   
   # create the config file
@@ -794,7 +852,7 @@ sub create_config {
   print CONF qq|);\n\n|;
 
   close CONF;
-
+  
   foreach $key (sort @config) {
     $self->{$key} =~ s/\\\\/\\/g;
     $self->{$key} =~ s/\\'/'/g;
@@ -848,12 +906,12 @@ sub save_member {
     $self->{dbpasswd} = pack 'u', $self->{dbpasswd};
     chop $self->{dbpasswd};
   }
-  
+
   my $password = $self->{password};
   if (!$self->{encrypted}) {
     $self->{password} = crypt $self->{password}, substr($self->{login}, 0, 2) if $self->{password};
   }
-  
+
   if ($self->{'root login'}) {
     @config = qw(password);
   } else {
@@ -862,14 +920,14 @@ sub save_member {
   }
  
   # replace \r\n with \n
-  for (qw(address signature)) { $self->{$_} =~ s/\r?\n/\\n/g }
+  $self->{signature} =~ s/\r?\n/\\n/g;
 
   for (sort @config) { print CONF qq|$_=$self->{$_}\n| }
 
   print CONF "\n";
   close CONF;
   unlink "${memberfile}.LCK";
-  
+
   # create conf file
   if (! $self->{'root login'}) {
     $self->{password} = $password;
@@ -884,25 +942,23 @@ sub save_member {
     my $login = $self->{login};
     $login =~ s/@.*//;
     my $query = qq|SELECT id FROM employee WHERE login = '$login'|;
-    my $sth = $dbh->prepare($query);
-    $sth->execute;
-
-    my ($id) = $sth->fetchrow_array;
-    $sth->finish;
+    my ($id) = $dbh->selectrow_array($query);
 
     if ($id) {
       $query = qq|UPDATE employee SET
                   role = '$self->{role}',
 		  email = '$self->{email}',
+		  workphone = '$self->{tel}',
+		  workfax = '$self->{fax}',
 		  name = '$self->{name}'
                   WHERE login = '$login'|;
 
     } else {
-      my ($employeenumber) = Form::update_defaults("", \%$self, "employeenumber", $dbh);
-      $query = qq|INSERT INTO employee (login, employeenumber, name, workphone,
+      $query = qq|INSERT INTO employee (login, name, workphone, workfax,
                   role, email, sales)
-		  VALUES ('$login', '$employeenumber', '$self->{name}',
-		  '$self->{tel}', '$self->{role}', '$self->{email}', '1')|;
+		  VALUES ('$login', '$self->{name}',
+		  '$self->{tel}', '$self->{fax}', '$self->{role}',
+		  '$self->{email}', '1')|;
     }
     
     $dbh->do($query);
@@ -923,11 +979,7 @@ sub delete_login {
   $login =~ s/@.*//;
   my $query = qq|SELECT id FROM employee
                  WHERE login = '$login'|; 
-  my $sth = $dbh->prepare($query);
-  $sth->execute || $form->dberror($query);
-  
-  my ($id) = $sth->fetchrow_array;
-  $sth->finish;
+  my ($id) = $dbh->selectrow_array($query);
 	
   my $query = qq|UPDATE employee SET
 		 login = NULL,
@@ -942,12 +994,12 @@ sub delete_login {
 
 
 sub config_vars {
- 
-  my @conf = qw(acs address businessnumber company countrycode currency
-             dateformat dbconnect dbdriver dbhost dbname dboptions
-	     dbpasswd dbport dbuser email fax menuwidth name numberformat
-	     password printer sessionkey role sid signature stylesheet tel
-	     templates timeout vclimit);
+
+  my @conf = qw(acs company countrycode dateformat
+             dbconnect dbdriver dbhost dbname dboptions dbpasswd
+	     dbport dbuser email fax menuwidth name numberformat password
+	     outputformat printer role sessionkey sid signature
+	     stylesheet tel templates timeout vclimit);
 
   @conf;
 
